Unit MyGraph;

interface

  uses
    Graph, InOut, Arrays;

  function XSc(x : real) : word;
  function YSc(y : real) : word;
  procedure GraphError;
  procedure SetWindow(x1, y1, x2, y2 : word; xmin, xmax, ymin, ymax : real);
  procedure SetPoints(n : byte; x, y : ArrType; DrawLine : boolean);

implementation

  var
    Cfx, Cfy, XminGl, YmaxGl : real;

  function XSc(x : real) : word;
   begin  { XSc }
     XSc := Trunc((x - XminGl) * Cfx);
   end;  { XSc }

  function YSc(y : real) : word;
   begin  { YSc }
     YSc := Trunc((YmaxGl - y) * Cfy);
   end;  { YSc }

  procedure GraphError;
   var
     Error : integer;
   begin { GraphError }
     Error := GraphResult;
     if (Error <> grOK)  then
       begin
         PutError(' ᪠ 訡: ' + GraphErrorMsg(Error));
         Halt;
       end;
   end;  { GraphError }

  procedure DrawAxis(xmin, xmax, ymin, ymax : real);
   var
     xc, yc : word;
   begin  { DrawAxis }

     if ((ymin * ymax) < 0)  then
       yc := YSc(0)
     else  if (ymax > 0)  then
       yc := YSc(ymin)
     else
       yc := YSc(ymax);
     Line(XSc(xmin), yc, XSc(xmax), yc);  {   }
     OutTextXY(XSc(xmax)-15, yc-10, 'X');

     if ((xmin * xmax) < 0)  then
       xc := XSc(0)
     else  if (xmin > 0)  then
       xc := XSc(xmin)
     else
       xc := XSc(xmax);
     Line(xc, YSc(ymin), xc, YSc(ymax));  {  न }
     OutTextXY(xc+15, YSc(ymax)+10, 'Y');

   end;  { DrawAxis }

  procedure SetWindow(x1, y1, x2, y2 : word; xmin, xmax, ymin, ymax : real);
   begin  { SetWindow }
     Cfx := (x2 - x1) / (xmax - xmin);
     Cfy := (y2 - y1) / (ymax - ymin);
     XminGl := xmin;  YmaxGl := ymax;
   {  Rectangle(x1-20, y1-20, x2+20, y2+20); }
     SetViewPort(x1, y1, x2, y2, ClipOn);
     DrawAxis(xmin, xmax, ymin, ymax);
   end;  { SetWindow }

  procedure SetPoints(n : byte; x, y : ArrType; DrawLine : boolean);
   var i : byte;
   begin  { SetPoints }
     MoveTo(XSc(x[1]), YSc(y[1]));  PutPixel(XSc(x[1]), YSc(y[1]), 1);
     for i := 2 to n  do
       if  DrawLine  then
         LineTo(XSc(x[i]), YSc(y[i]))
       else
         PutPixel(XSc(x[i]), YSc(y[i]), 1);
   end;  { SetPoints }

end.